@@ -20,15 +20,17 @@
 
 
 #include <QApplication>
+#include <QDebug>
+
 #include "rvln.h"
 
-
+#include "single_application.h"
 
 
 int main (int argc, char *argv[])
 {
-  Q_INIT_RESOURCE (rlvn);
-
+// Q_INIT_RESOURCE (rlvn);
+/*
   CApplication app (argc, argv);
   qApp->setApplicationName ("TEA");
   
@@ -37,4 +39,45 @@ int main (int argc, char *argv[])
   mw.show();
 
   return app.exec();
+  
+  */
+
+  //Q_INIT_RESOURCE (rlvn);
+  
+ // qDebug() << "1";
+  
+  SingleApplication app (argc, argv, "tea unique id 1977");
+  
+ // qDebug() << "2";
+  
+  
+  if (app.isRunning())
+     {
+       
+       if (argc > 1)
+          for (int i = 1; i < argc; i++) 
+               app.sendMessage (QString(argv[i]));
+       
+       return 0;
+     }
+  
+ // qDebug() << "3";
+  
+  
+  rvln *mainWindow = new rvln();
+
+ // qDebug() << "4";
+  
+  
+  QObject::connect(&app, SIGNAL(messageAvailable(QString)), mainWindow, SLOT(receiveMessage(QString)));
+
+ // qDebug() << "5";
+  
+  
+  mainWindow->show();
+
+ // qDebug() << "6";
+  
+  
+  return app.exec();   
 }
