@@ -51,6 +51,8 @@
 #include <QTranslator>
 #include <QProcess>
 
+//#include <QSystemTrayIcon>
+
 
 //QML stuff
 #if QT_VERSION >= 0x050000
@@ -187,9 +189,10 @@ public:
 
   bool portable_mode;
 
-  //CScriptedApp *scripted_app;
   CLogMemo *log;
   
+  //QSystemTrayIcon tray_icon;
+  
   CShortcuts *shortcuts;
   CFMan *fman;
   CImgViewer *img_viewer;
@@ -229,14 +232,7 @@ public:
   bool ui_update;
   QString fname_storage_file;
 
-
   QHash <QString, CMarkupPair*> hs_markup;
-  //QHash <QString, CMarkupPair2*> hs_markup2;
-  
-//   QHash <QString, THashStringPair*> hs_markup2;
-
-  
-  
 
   QToolBar *tb_fman_dir;
   QLabel *l_fman_preview;
@@ -264,7 +260,6 @@ public:
 
 #ifdef PRINTER_ENABLE
 
-
   QPrinter printer;
 
 #endif
@@ -350,6 +345,9 @@ public:
   QComboBox *cmb_output_image_fmt;
   QCheckBox *cb_output_image_flt;
 
+  QComboBox *cmb_tea_icons;
+  
+  
   QComboBox *cmb_ui_langs;
 
   QSpinBox *spb_img_quality;
@@ -358,6 +356,8 @@ public:
 
 protected:
 
+ // void keyPressEvent (QKeyEvent *event);    
+
   void closeEvent (QCloseEvent *event);
   bool fman_tv_eventFilter (QObject *obj, QEvent *event);
 
@@ -368,12 +368,13 @@ public slots:
 main window callbacks
 *************************/
 
+  void receiveMessage(const QString &msg);
+  
+
   void select_label();
   void update_labels_menu();
   void update_labels_list();
 
-  //void ed_variants();
-
   
   void fm_full_info();
 
@@ -617,6 +618,7 @@ main window callbacks
   void search_fuzzy_mode();
   void search_regexp_mode();
   void search_whole_words_mode();
+  void search_from_cursor_mode();
 
 
   void search_find();
@@ -699,12 +701,14 @@ prefs window callbacks
 
   void cmb_ui_langs_currentIndexChanged (const QString &text);
 
+  void cb_altmenu_stateChanged (int state);
 
   void cmb_ui_tabs_currentIndexChanged (int i);
   void cmb_docs_tabs_currentIndexChanged (int i);
 
 
   void cmb_icon_sizes_currentIndexChanged (const QString &text);
+  void cmb_tea_icons_currentIndexChanged  (const QString &text);
 
   void pb_assign_hotkey_clicked();
   void pb_remove_hotkey_clicked();
@@ -818,6 +822,8 @@ main window widgets
   QAction *aboutAct;
   QAction *aboutQtAct;
   QAction *menu_find_whole_words;
+  QAction *menu_find_from_cursor;
+  
   QAction *menu_find_case;
   QAction *menu_find_regexp;
   QAction *menu_find_fuzzy;
@@ -830,6 +836,7 @@ main window widgets
   QComboBox *cmb_styles;
   QComboBox *cmb_icon_size;
 
+  
   CCalendarWidget *calendar;
 
 /*************************
@@ -862,12 +869,16 @@ prefs window widgets
   QListWidget *lv_places;
   QSplitter *spl_fman;
 
+  QCheckBox *cb_altmenu;
+  
 
   QCheckBox *cb_auto_img_preview;
   QCheckBox *cb_override_locale;
 
   QCheckBox *cb_override_img_viewer;
 
+  QComboBox *cmb_cmdline_default_charset;
+  
   
   QComboBox *cmb_zip_charset_in;
   QComboBox *cmb_zip_charset_out;
