@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyleft 2007-2013 by Peter Semiletov                            *
+ *   Copyleft 2007-2014 by Peter Semiletov                            *
  *   tea@list.ru                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -228,5 +228,5 @@ void CShortcutEntry::keyPressEvent (QKeyEvent *event)
   event->accept();
   QString text = mod_to_string (event->modifiers()) + keycode_to_string (event->key());
   setText (text);
-  qDebug() << text;
+  //qDebug() << text;
 }
